pub struct TxnData<'a> {
pub compares: Vec<Compare<'a>>,
pub success: Vec<Operation<'a>>,
pub failure: Vec<Operation<'a>>,
}Expand description
A transactional data structure.
Fields
compares: Vec<Compare<'a>>A list of operations to compare against the current state.
success: Vec<Operation<'a>>A list of operations to apply if the compare operations pass.
failure: Vec<Operation<'a>>A list of operations to apply if the compare operations fail.