Function parse

pub fn parse(data: &[u8]) -> ParseResult<TxnData<'_>>
Parse a transactional data structure from a byte slice.

Errors

If the parser encounters an unexpected token, a ParseError is returned.

Examples